
==============
Test API Docs
==============

.. _api-contents:

--------------------
Modules and Packages
--------------------

.. autosummary::

   exso
   exso.Updater


-----------------------
``exso`` root package
-----------------------

.. automodule:: haggis
   :members:

   ----------
   Attributes
   ----------

   .. attribute:: __version__

      The current version is |release|.


---------------
``Updater`` module
---------------

.. automodule:: exso.Updater
   :members:
   :private-members:
   :special-members:
